@@ -1,12 +1,13 @@
 import json
 from tornado import web
-from jupyterhub.apihandlers import  APIHandler, default_handlers
+from jupyterhub.apihandlers import APIHandler, default_handlers
+
 
 class BatchSpawnerAPIHandler(APIHandler):
     @web.authenticated
     def post(self):
         """POST set user spawner data"""
-        if hasattr(self, 'current_user'):
+        if hasattr(self, "current_user"):
             # Jupyterhub compatability, (september 2018, d79a99323ef1d)
             user = self.current_user
         else:
@@ -25,4 +26,5 @@ class BatchSpawnerAPIHandler(APIHandler):
         self.finish(json.dumps({"message": "BatchSpawner data configured"}))
         self.set_status(201)
 
+
 default_handlers.append((r"/api/batchspawner", BatchSpawnerAPIHandler))
